@@ -1,5 +1,5 @@
 /*
- * Copyright 2008 Benjamin C. Meyer <ben@meyerhome.net>
+ * Copyright 2008-2009 Benjamin C. Meyer <ben@meyerhome.net>
  * Copyright 2008 Jason A. Donenfeld <Jason@zx2c4.com>
  * Copyright 2008 Ariya Hidayat <ariya.hidayat@gmail.com>
  *
@@ -65,6 +65,7 @@
 #include "browsermainwindow.h"
 
 #include "aboutdialog.h"
+#include "adblockmanager.h"
 #include "addbookmarkdialog.h"
 #include "autosaver.h"
 #include "bookmarksdialog.h"
@@ -78,6 +79,7 @@
 #include "history.h"
 #include "languagemanager.h"
 #include "networkaccessmanager.h"
+#include "opensearchdialog.h"
 #include "settings.h"
 #include "sourceviewer.h"
 #include "tabbar.h"
@@ -132,12 +134,11 @@ BrowserMainWindow::BrowserMainWindow(QWidget *parent, Qt::WindowFlags flags)
     QWidget *centralWidget = new QWidget(this);
     BookmarksModel *boomarksModel = BrowserApplication::bookmarksManager()->bookmarksModel();
     m_bookmarksToolbar = new BookmarksToolBar(boomarksModel, this);
+    m_bookmarksToolbar->setObjectName(QLatin1String("BookmarksToolbar"));
     connect(m_bookmarksToolbar, SIGNAL(openUrl(const QUrl&, const QString&)),
             m_tabWidget, SLOT(loadUrlFromUser(const QUrl&, const QString&)));
     connect(m_bookmarksToolbar, SIGNAL(openUrl(const QUrl&, TabWidget::OpenUrlIn, const QString&)),
             m_tabWidget, SLOT(loadUrl(const QUrl&, TabWidget::OpenUrlIn, const QString&)));
-    connect(m_bookmarksToolbar->toggleViewAction(), SIGNAL(toggled(bool)),
-            this, SLOT(updateBookmarksToolbarActionText(bool)));
 
     QVBoxLayout *layout = new QVBoxLayout;
     layout->setSpacing(0);
@@ -206,7 +207,7 @@ BrowserMainWindow::BrowserMainWindow(QWidget *parent, Qt::WindowFlags flags)
     updateWindowTitle();
     loadDefaultState();
     m_tabWidget->newTab();
-    m_tabWidget->currentLineEdit()->setFocus();
+    m_tabWidget->currentLocationBar()->setFocus();
 #if defined(Q_WS_MAC)
     m_navigationBar->setIconSize(QSize(18, 18));
 #endif
@@ -234,25 +235,42 @@ BrowserMainWindow::~BrowserMainWindow()
     m_autoSaver->saveIfNeccessary();
 }
 
+void BrowserMainWindow::keyPressEvent(QKeyEvent *event)
+{
+    switch (event->key()) {
+    case Qt::Key_HomePage:
+        m_historyHomeAction->trigger();
+        event->accept();
+        break;
+    case Qt::Key_Favorites:
+        m_bookmarksShowAllAction->trigger();
+        event->accept();
+        break;
+    case Qt::Key_Search:
+        m_toolsWebSearchAction->trigger();
+        event->accept();
+        break;
+    case Qt::Key_OpenUrl:
+        m_fileOpenLocationAction->trigger();
+        event->accept();
+        break;
+    default:
+        QMainWindow::keyPressEvent(event);
+        break;
+    }
+}
+
 BrowserMainWindow *BrowserMainWindow::parentWindow(QWidget *widget)
 {
-    BrowserMainWindow *parentWindow = 0;
-
     while (widget) {
-        if (BrowserMainWindow *parent = qobject_cast<BrowserMainWindow*>(widget)) {
-            parentWindow = parent;
-            break;
-        }
+        if (BrowserMainWindow *parent = qobject_cast<BrowserMainWindow*>(widget))
+            return parent;
 
         widget = widget->parentWidget();
     }
 
-    if (!parentWindow) {
-        qWarning() << "BrowserMainWindow::" << __FUNCTION__ << " used with a widget none of whose parents is a main window.";
-        parentWindow = BrowserApplication::instance()->mainWindow();
-    }
-
-    return parentWindow;
+    qWarning() << "BrowserMainWindow::" << __FUNCTION__ << " used with a widget none of whose parents is a main window.";
+    return BrowserApplication::instance()->mainWindow();
 }
 
 void BrowserMainWindow::loadDefaultState()
@@ -295,8 +313,8 @@ QByteArray BrowserMainWindow::saveState(bool withTabs) const
 
     // save the normal size so exiting fullscreen/maximize will work reasonably
     stream << normalGeometry().size();
-    stream << !m_navigationBar->isHidden();
-    stream << !m_bookmarksToolbar->isHidden();
+    stream << !m_navigationBar->isHidden(); // DEAD
+    stream << !m_bookmarksToolbar->isHidden(); // DEAD
     stream << !statusBar()->isHidden();
     if (withTabs)
         stream << tabWidget()->saveState();
@@ -311,10 +329,12 @@ QByteArray BrowserMainWindow::saveState(bool withTabs) const
     // version 3
     stream << isMaximized();
     stream << isFullScreen();
-    stream << !menuBar()->isHidden();
-    stream << m_menuBarVisible;
+    stream << menuBar()->isVisible();
+    stream << m_menuBarVisible; // DEAD
     stream << m_statusBarVisible;
 
+    stream << QMainWindow::saveState();
+
     return data;
 }
 
@@ -333,8 +353,8 @@ bool BrowserMainWindow::restoreState(const QByteArray &state)
         return false;
 
     QSize size;
-    bool showToolbar;
-    bool showBookmarksBar;
+    bool showToolbarDEAD;
+    bool showBookmarksBarDEAD;
     bool showStatusbar;
     QByteArray tabState;
     QByteArray splitterState;
@@ -344,10 +364,11 @@ bool BrowserMainWindow::restoreState(const QByteArray &state)
     bool maximized;
     bool fullScreen;
     bool showMenuBar;
+    QByteArray qMainWindowState;
 
     stream >> size;
-    stream >> showToolbar;
-    stream >> showBookmarksBar;
+    stream >> showToolbarDEAD;
+    stream >> showBookmarksBarDEAD;
     stream >> showStatusbar;
     stream >> tabState;
     stream >> splitterState;
@@ -359,28 +380,19 @@ bool BrowserMainWindow::restoreState(const QByteArray &state)
         stream >> maximized;
         stream >> fullScreen;
         stream >> showMenuBar;
-        stream >> m_menuBarVisible;
+        stream >> showMenuBar; // m_menuBarVisible DEAD
         stream >> m_statusBarVisible;
+        stream >> qMainWindowState;
     } else {
         maximized = false;
         fullScreen = false;
         showMenuBar = true;
-        m_menuBarVisible = true;
         m_statusBarVisible = showStatusbar;
     }
 
     if (size.isValid())
         resize(size);
 
-    m_navigationBar->setVisible(showToolbar);
-    updateToolbarActionText(showToolbar);
-
-    m_bookmarksToolbar->setVisible(showBookmarksBar);
-#if defined(Q_WS_MAC)
-    m_bookmarksToolbarFrame->setVisible(showBookmarksBar);
-#endif
-    updateBookmarksToolbarActionText(showBookmarksBar);
-
     if (maximized)
         setWindowState(windowState() | Qt::WindowMaximized);
     if (fullScreen) {
@@ -389,23 +401,32 @@ bool BrowserMainWindow::restoreState(const QByteArray &state)
     }
 
     menuBar()->setVisible(showMenuBar);
+    m_menuBarVisible = showMenuBar;
 
     statusBar()->setVisible(showStatusbar);
-    updateStatusbarActionText(showStatusbar);
 
     m_navigationSplitter->restoreState(splitterState);
 
-    if (!tabState.isEmpty() && !tabWidget()->restoreState(tabState))
-        return false;
+    tabWidget()->restoreState(tabState);
 
     m_tabWidget->tabBar()->setShowTabBarWhenOneTab(showTabBarWhenOneTab);
 
-    Qt::ToolBarArea navigationArea = Qt::ToolBarArea(navigationBarLocation);
-    if (navigationArea != Qt::TopToolBarArea && navigationArea != Qt::NoToolBarArea)
-        addToolBar(navigationArea, m_navigationBar);
-    Qt::ToolBarArea bookmarkArea = Qt::ToolBarArea(bookmarkBarLocation);
-    if (bookmarkArea != Qt::TopToolBarArea && bookmarkArea != Qt::NoToolBarArea)
-        addToolBar(bookmarkArea, m_bookmarksToolbar);
+    if (qMainWindowState.isEmpty()) {
+        m_navigationBar->setVisible(showToolbarDEAD);
+        m_bookmarksToolbar->setVisible(showBookmarksBarDEAD);
+        Qt::ToolBarArea navigationArea = Qt::ToolBarArea(navigationBarLocation);
+        if (navigationArea != Qt::TopToolBarArea && navigationArea != Qt::NoToolBarArea)
+            addToolBar(navigationArea, m_navigationBar);
+        Qt::ToolBarArea bookmarkArea = Qt::ToolBarArea(bookmarkBarLocation);
+        if (bookmarkArea != Qt::TopToolBarArea && bookmarkArea != Qt::NoToolBarArea)
+            addToolBar(bookmarkArea, m_bookmarksToolbar);
+    } else {
+        QMainWindow::restoreState(qMainWindowState);
+    }
+
+#if defined(Q_WS_MAC)
+    m_bookmarksToolbarFrame->setVisible(m_bookmarksToolbar->isVisible());
+#endif
 
     return true;
 }
@@ -516,6 +537,16 @@ void BrowserMainWindow::setupMenu()
     m_fileQuit->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_Q));
     m_fileMenu->addAction(m_fileQuit);
 
+#if QT_VERSION >= 0x040600 && defined(Q_WS_X11)
+    m_fileNewWindowAction->setIcon(QIcon::fromTheme(QLatin1String("window-new")));
+    m_fileOpenFileAction->setIcon(QIcon::fromTheme(QLatin1String("document-open")));
+    m_filePrintPreviewAction->setIcon(QIcon::fromTheme(QLatin1String("document-print-preview")));
+    m_filePrintAction->setIcon(QIcon::fromTheme(QLatin1String("document-print")));
+    m_fileSaveAsAction->setIcon(QIcon::fromTheme(QLatin1String("document-save-as")));
+    m_fileCloseWindow->setIcon(QIcon::fromTheme(QLatin1String("window-close")));
+    m_fileQuit->setIcon(QIcon::fromTheme(QLatin1String("application-exit")));
+#endif
+
     // Edit
     m_editMenu = new QMenu(menuBar());
     menuBar()->addMenu(m_editMenu);
@@ -540,6 +571,10 @@ void BrowserMainWindow::setupMenu()
     m_editPasteAction->setShortcuts(QKeySequence::Paste);
     m_tabWidget->addWebAction(m_editPasteAction, QWebPage::Paste);
     m_editMenu->addAction(m_editPasteAction);
+    m_editSelectAllAction = new QAction(m_editMenu);
+    m_editSelectAllAction->setShortcuts(QKeySequence::SelectAll);
+    m_tabWidget->addWebAction(m_editSelectAllAction, QWebPage::SelectAll);
+    m_editMenu->addAction(m_editSelectAllAction);
     m_editMenu->addSeparator();
 
     m_editFindAction = new QAction(m_editMenu);
@@ -558,27 +593,32 @@ void BrowserMainWindow::setupMenu()
     connect(m_editFindPreviousAction, SIGNAL(triggered()), this, SLOT(editFindPrevious()));
     m_editMenu->addAction(m_editFindPreviousAction);
 
-    m_editMenu->addSeparator();
-    m_editPreferencesAction = new QAction(m_editMenu);
-    connect(m_editPreferencesAction, SIGNAL(triggered()),
-            this, SLOT(preferences()));
-    m_editMenu->addAction(m_editPreferencesAction);
+#if QT_VERSION >= 0x040600 && defined(Q_WS_X11)
+    m_editUndoAction->setIcon(QIcon::fromTheme(QLatin1String("edit-undo")));
+    m_editRedoAction->setIcon(QIcon::fromTheme(QLatin1String("edit-redo")));
+    m_editCutAction->setIcon(QIcon::fromTheme(QLatin1String("edit-cut")));
+    m_editCopyAction->setIcon(QIcon::fromTheme(QLatin1String("edit-copy")));
+    m_editPasteAction->setIcon(QIcon::fromTheme(QLatin1String("edit-paste")));
+    m_editSelectAllAction->setIcon(QIcon::fromTheme(QLatin1String("edit-select-all")));
+    m_editFindAction->setIcon(QIcon::fromTheme(QLatin1String("edit-find")));
+#endif
 
     // View
     m_viewMenu = new QMenu(menuBar());
+    connect(m_viewMenu, SIGNAL(aboutToShow()),
+            this, SLOT(aboutToShowViewMenu()));
     menuBar()->addMenu(m_viewMenu);
+
     m_viewShowMenuBarAction = new QAction(m_viewMenu);
     m_viewShowMenuBarAction->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_M));
     connect(m_viewShowMenuBarAction, SIGNAL(triggered()), this, SLOT(viewMenuBar()));
     addAction(m_viewShowMenuBarAction);
 
     m_viewToolbarAction = new QAction(this);
-    updateToolbarActionText(true);
     connect(m_viewToolbarAction, SIGNAL(triggered()), this, SLOT(viewToolbar()));
     m_viewMenu->addAction(m_viewToolbarAction);
 
     m_viewBookmarkBarAction = new QAction(m_viewMenu);
-    updateBookmarksToolbarActionText(true);
     connect(m_viewBookmarkBarAction, SIGNAL(triggered()), this, SLOT(viewBookmarksBar()));
     m_viewMenu->addAction(m_viewBookmarkBarAction);
 
@@ -588,7 +628,6 @@ void BrowserMainWindow::setupMenu()
             m_autoSaver, SLOT(changeOccurred()));
 
     m_viewStatusbarAction = new QAction(m_viewMenu);
-    updateStatusbarActionText(true);
     connect(m_viewStatusbarAction, SIGNAL(triggered()), this, SLOT(viewStatusbar()));
     m_viewMenu->addAction(m_viewStatusbarAction);
 
@@ -636,13 +675,11 @@ void BrowserMainWindow::setupMenu()
 
     m_viewZoomTextOnlyAction = new QAction(m_viewMenu);
     m_viewZoomTextOnlyAction->setCheckable(true);
-#if QT_VERSION >= 0x040500
     connect(m_viewZoomTextOnlyAction, SIGNAL(toggled(bool)),
             BrowserApplication::instance(), SLOT(setZoomTextOnly(bool)));
     connect(BrowserApplication::instance(), SIGNAL(zoomTextOnlyChanged(bool)),
             this, SLOT(zoomTextOnlyChanged(bool)));
     m_viewMenu->addAction(m_viewZoomTextOnlyAction);
-#endif
 
     m_viewFullScreenAction = new QAction(m_viewMenu);
     m_viewFullScreenAction->setShortcut(Qt::Key_F11);
@@ -672,6 +709,17 @@ void BrowserMainWindow::setupMenu()
             this, SLOT(viewTextEncoding(QAction *)));
 #endif
 
+    m_stopIcon = style()->standardIcon(QStyle::SP_BrowserStop);
+    m_reloadIcon = style()->standardIcon(QStyle::SP_BrowserReload);
+#if QT_VERSION >= 0x040600 && defined(Q_WS_X11)
+    m_viewStopAction->setIcon(m_stopIcon);
+    m_viewReloadAction->setIcon(m_reloadIcon);
+    m_viewZoomInAction->setIcon(QIcon::fromTheme(QLatin1String("zoom-in")));
+    m_viewZoomNormalAction->setIcon(QIcon::fromTheme(QLatin1String("zoom-original")));
+    m_viewZoomOutAction->setIcon(QIcon::fromTheme(QLatin1String("zoom-out")));
+    m_viewFullScreenAction->setIcon(QIcon::fromTheme(QLatin1String("view-fullscreen")));
+#endif
+
     // History
     m_historyMenu = new HistoryMenu(this);
     connect(m_historyMenu, SIGNAL(openUrl(const QUrl&, const QString&)),
@@ -682,12 +730,16 @@ void BrowserMainWindow::setupMenu()
     m_historyBackAction = new QAction(this);
     m_tabWidget->addWebAction(m_historyBackAction, QWebPage::Back);
     m_historyBackAction->setShortcuts(QKeySequence::Back);
+#if QT_VERSION < 0x040600 || (QT_VERSION >= 0x040600 && !defined(Q_WS_X11))
     m_historyBackAction->setIconVisibleInMenu(false);
+#endif
 
     m_historyForwardAction = new QAction(this);
     m_tabWidget->addWebAction(m_historyForwardAction, QWebPage::Forward);
     m_historyForwardAction->setShortcuts(QKeySequence::Forward);
+#if QT_VERSION < 0x040600 || (QT_VERSION >= 0x040600 && !defined(Q_WS_X11))
     m_historyForwardAction->setIconVisibleInMenu(false);
+#endif
 
     m_historyHomeAction = new QAction(this);
     connect(m_historyHomeAction, SIGNAL(triggered()), this, SLOT(goHome()));
@@ -704,6 +756,10 @@ void BrowserMainWindow::setupMenu()
     historyActions.append(m_tabWidget->recentlyClosedTabsAction());
     historyActions.append(m_historyRestoreLastSessionAction);
     m_historyMenu->setInitialActions(historyActions);
+#if QT_VERSION >= 0x040600 && defined(Q_WS_X11)
+    m_historyRestoreLastSessionAction->setIcon(QIcon::fromTheme(QLatin1String("document-revert")));
+    m_historyHomeAction->setIcon(QIcon::fromTheme(QLatin1String("go-home")));
+#endif
 
     // Bookmarks
     m_bookmarksMenu = new BookmarksMenuBarMenu(this);
@@ -720,7 +776,9 @@ void BrowserMainWindow::setupMenu()
 
     m_bookmarksAddAction = new QAction(this);
     m_bookmarksAddAction->setIcon(QIcon(QLatin1String(":addbookmark.png")));
+#if QT_VERSION < 0x040600 || (QT_VERSION >= 0x040600 && !defined(Q_WS_X11))
     m_bookmarksAddAction->setIconVisibleInMenu(false);
+#endif
     connect(m_bookmarksAddAction, SIGNAL(triggered()),
             this, SLOT(addBookmark()));
     m_bookmarksAddAction->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_D));
@@ -736,6 +794,11 @@ void BrowserMainWindow::setupMenu()
     bookmarksActions.append(m_bookmarksAddFolderAction);
     m_bookmarksMenu->setInitialActions(bookmarksActions);
 
+#if QT_VERSION >= 0x040600
+    m_bookmarksAddFolderAction->setIcon(QIcon::fromTheme(QLatin1String("folder-new")));
+    m_bookmarksShowAllAction->setIcon(QIcon::fromTheme(QLatin1String("user-bookmarks")));
+#endif
+
     // Window
     m_windowMenu = new QMenu(menuBar());
     menuBar()->addMenu(m_windowMenu);
@@ -757,14 +820,30 @@ void BrowserMainWindow::setupMenu()
             this, SLOT(clearPrivateData()));
     m_toolsMenu->addAction(m_toolsClearPrivateDataAction);
 
-    m_toolsEnableInspector = new QAction(m_toolsMenu);
-    connect(m_toolsEnableInspector, SIGNAL(triggered(bool)),
+    m_toolsEnableInspectorAction = new QAction(m_toolsMenu);
+    connect(m_toolsEnableInspectorAction, SIGNAL(triggered(bool)),
             this, SLOT(toggleInspector(bool)));
-    m_toolsEnableInspector->setCheckable(true);
+    m_toolsEnableInspectorAction->setCheckable(true);
     QSettings settings;
     settings.beginGroup(QLatin1String("websettings"));
-    m_toolsEnableInspector->setChecked(settings.value(QLatin1String("enableInspector"), false).toBool());
-    m_toolsMenu->addAction(m_toolsEnableInspector);
+    m_toolsEnableInspectorAction->setChecked(settings.value(QLatin1String("enableInspector"), false).toBool());
+    m_toolsMenu->addAction(m_toolsEnableInspectorAction);
+
+    m_toolsSearchManagerAction = new QAction(m_toolsMenu);
+    connect(m_toolsSearchManagerAction, SIGNAL(triggered()),
+            this, SLOT(showSearchDialog()));
+    m_toolsMenu->addAction(m_toolsSearchManagerAction);
+
+    m_adBlockDialogAction = new QAction(m_toolsMenu);
+    connect(m_adBlockDialogAction, SIGNAL(triggered()),
+            AdBlockManager::instance(), SLOT(showDialog()));
+    m_toolsMenu->addAction(m_adBlockDialogAction);
+
+    m_toolsMenu->addSeparator();
+    m_toolsPreferencesAction = new QAction(m_editMenu);
+    connect(m_toolsPreferencesAction, SIGNAL(triggered()),
+            this, SLOT(preferences()));
+    m_toolsMenu->addAction(m_toolsPreferencesAction);
 
     // Help
     m_helpMenu = new QMenu(menuBar());
@@ -785,8 +864,20 @@ void BrowserMainWindow::setupMenu()
     connect(m_helpAboutApplicationAction, SIGNAL(triggered()),
             this, SLOT(aboutApplication()));
     m_helpMenu->addAction(m_helpAboutApplicationAction);
+
+#if QT_VERSION >= 0x040600 && defined(Q_WS_X11)
+    m_helpChangeLanguageAction->setIcon(QIcon::fromTheme(QLatin1String("preferences-desktop-locale")));
+    m_helpAboutQtAction->setIcon(QPixmap(QLatin1String(":/trolltech/qmessagebox/images/qtlogo-64.png")));
+    m_helpAboutApplicationAction->setIcon(windowIcon());
+#endif
 }
 
+void BrowserMainWindow::aboutToShowViewMenu()
+{
+    m_viewToolbarAction->setText(m_navigationBar->isVisible() ? tr("Hide Toolbar") : tr("Show Toolbar"));
+    m_viewBookmarkBarAction->setText(m_bookmarksToolbar->isVisible() ? tr("Hide Bookmarks Bar") : tr("Show Bookmarks Bar"));
+    m_viewStatusbarAction->setText(statusBar()->isVisible() ? tr("Hide Status Bar") : tr("Show Status Bar"));
+}
 
 void BrowserMainWindow::aboutToShowTextEncodingMenu()
 {
@@ -858,15 +949,14 @@ void BrowserMainWindow::retranslate()
     m_editCutAction->setText(tr("Cu&t"));
     m_editCopyAction->setText(tr("&Copy"));
     m_editPasteAction->setText(tr("&Paste"));
+    m_editSelectAllAction->setText(tr("Select &All"));
     m_editFindAction->setText(tr("&Find"));
     m_editFindNextAction->setText(tr("Find Nex&t"));
     m_editFindPreviousAction->setText(tr("Find P&revious"));
-    m_editPreferencesAction->setText(tr("Prefere&nces..."));
-    m_editPreferencesAction->setShortcut(tr("Ctrl+,"));
 
     m_viewMenu->setTitle(tr("&View"));
     m_viewToolbarAction->setShortcut(tr("Ctrl+|"));
-    m_viewBookmarkBarAction->setShortcut(tr("Shift+Ctrl+B"));
+    m_viewBookmarkBarAction->setShortcut(tr("Alt+Ctrl+B"));
     m_viewStatusbarAction->setShortcut(tr("Ctrl+/"));
     m_viewShowMenuBarAction->setText(tr("Show Menu Bar"));
     m_viewReloadAction->setText(tr("&Reload Page"));
@@ -900,7 +990,11 @@ void BrowserMainWindow::retranslate()
     m_toolsWebSearchAction->setShortcut(QKeySequence(tr("Ctrl+K", "Web Search")));
     m_toolsClearPrivateDataAction->setText(tr("&Clear Private Data"));
     m_toolsClearPrivateDataAction->setShortcut(QKeySequence(tr("Ctrl+Shift+Delete", "Clear Private Data")));
-    m_toolsEnableInspector->setText(tr("Enable Web &Inspector"));
+    m_toolsEnableInspectorAction->setText(tr("Enable Web &Inspector"));
+    m_toolsPreferencesAction->setText(tr("Options..."));
+    m_toolsPreferencesAction->setShortcut(tr("Ctrl+,"));
+    m_toolsSearchManagerAction->setText(tr("Configure Search Engines..."));
+    m_adBlockDialogAction->setText(tr("&Ad Block..."));
 
     m_helpMenu->setTitle(tr("&Help"));
     m_helpChangeLanguageAction->setText(tr("Switch application language "));
@@ -909,18 +1003,15 @@ void BrowserMainWindow::retranslate()
 
     // Toolbar
     m_navigationBar->setWindowTitle(tr("Navigation"));
-    updateStatusbarActionText(m_statusBarVisible);
-    updateToolbarActionText(m_navigationBar->isVisible());
-    updateBookmarksToolbarActionText(m_bookmarksToolbar->isVisible());
+    m_bookmarksToolbar->setWindowTitle(tr("&Bookmarks"));
 }
 
 void BrowserMainWindow::setupToolBar()
 {
     setUnifiedTitleAndToolBarOnMac(true);
     m_navigationBar = new QToolBar(this);
+    m_navigationBar->setObjectName(QLatin1String("NavigationToolBar"));
     addToolBar(m_navigationBar);
-    connect(m_navigationBar->toggleViewAction(), SIGNAL(toggled(bool)),
-            this, SLOT(updateToolbarActionText(bool)));
 
     m_historyBackAction->setIcon(style()->standardIcon(QStyle::SP_ArrowBack, 0, this));
     m_historyBackMenu = new QMenu(this);
@@ -941,19 +1032,18 @@ void BrowserMainWindow::setupToolBar()
     m_navigationBar->addAction(m_historyForwardAction);
 
     m_stopReloadAction = new QAction(this);
-    m_reloadIcon = style()->standardIcon(QStyle::SP_BrowserReload);
     m_stopReloadAction->setIcon(m_reloadIcon);
     m_navigationBar->addAction(m_stopReloadAction);
 
     m_navigationSplitter = new QSplitter(m_navigationBar);
-    m_navigationSplitter->addWidget(m_tabWidget->lineEditStack());
+    m_navigationSplitter->addWidget(m_tabWidget->locationBarStack());
 
     m_toolbarSearch = new ToolbarSearch(m_navigationBar);
     m_navigationSplitter->addWidget(m_toolbarSearch);
     connect(m_toolbarSearch, SIGNAL(search(const QUrl&)),
             m_tabWidget, SLOT(loadUrl(const QUrl&)));
     m_navigationSplitter->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum);
-    m_tabWidget->lineEditStack()->setMinimumWidth(120);
+    m_tabWidget->locationBarStack()->setMinimumWidth(120);
     m_navigationSplitter->setCollapsible(0, false);
     m_navigationBar->addWidget(m_navigationSplitter);
     int splitterWidth = m_navigationSplitter->width();
@@ -1002,15 +1092,14 @@ void BrowserMainWindow::viewMenuBar()
     menuBar()->setVisible(!menuBar()->isVisible());
 
     m_menuBarVisible = menuBar()->isVisible();
+    m_autoSaver->changeOccurred();
 }
 
 void BrowserMainWindow::viewToolbar()
 {
     if (m_navigationBar->isVisible()) {
-        updateToolbarActionText(false);
         m_navigationBar->close();
     } else {
-        updateToolbarActionText(true);
         m_navigationBar->show();
     }
     m_autoSaver->changeOccurred();
@@ -1019,13 +1108,11 @@ void BrowserMainWindow::viewToolbar()
 void BrowserMainWindow::viewBookmarksBar()
 {
     if (m_bookmarksToolbar->isVisible()) {
-        updateBookmarksToolbarActionText(false);
         m_bookmarksToolbar->hide();
 #if defined(Q_WS_MAC)
         m_bookmarksToolbarFrame->hide();
 #endif
     } else {
-        updateBookmarksToolbarActionText(true);
         m_bookmarksToolbar->show();
 #if defined(Q_WS_MAC)
         m_bookmarksToolbarFrame->show();
@@ -1034,28 +1121,11 @@ void BrowserMainWindow::viewBookmarksBar()
     m_autoSaver->changeOccurred();
 }
 
-void BrowserMainWindow::updateStatusbarActionText(bool visible)
-{
-    m_viewStatusbarAction->setText(!visible ? tr("Show Status Bar") : tr("Hide Status Bar"));
-}
-
-void BrowserMainWindow::updateToolbarActionText(bool visible)
-{
-    m_viewToolbarAction->setText(!visible ? tr("Show Toolbar") : tr("Hide Toolbar"));
-}
-
-void BrowserMainWindow::updateBookmarksToolbarActionText(bool visible)
-{
-    m_viewBookmarkBarAction->setText(!visible ? tr("Show Bookmarks Bar") : tr("Hide Bookmarks Bar"));
-}
-
 void BrowserMainWindow::viewStatusbar()
 {
     if (statusBar()->isVisible()) {
-        updateStatusbarActionText(false);
         statusBar()->close();
     } else {
-        updateStatusbarActionText(true);
         statusBar()->show();
     }
 
@@ -1071,13 +1141,11 @@ void BrowserMainWindow::downloadManager()
 
 void BrowserMainWindow::selectLineEdit()
 {
-    if (m_navigationBar->isHidden()) {
+    if (m_navigationBar->isHidden())
         m_navigationBar->show();
-        updateToolbarActionText(true);
-    }
 
-    m_tabWidget->currentLineEdit()->selectAll();
-    m_tabWidget->currentLineEdit()->setFocus();
+    m_tabWidget->currentLocationBar()->selectAll();
+    m_tabWidget->currentLocationBar()->setFocus();
 }
 
 void BrowserMainWindow::fileSaveAs()
@@ -1170,25 +1238,30 @@ void BrowserMainWindow::privateBrowsing()
 {
     if (!BrowserApplication::isPrivate()) {
         QString title = tr("Are you sure you want to turn on private browsing?");
-        QString text = tr("<b>%1</b><br><br>When private browsing is turned on,"
-            " some actions concerning your privacy will be disabled:"
-            "<ul><li> Webpages are not added to the history.</li>"
-            "<li> Items are automatically removed from the Downloads window.</li>"
-            "<li> New cookies are not stored, current cookies can't be accessed.</li>"
-            "<li> Site icons won't be stored, session won't be saved.</li>"
-            "<li> Searches are not added to the pop-up menu in the search box.</li>"
-            "<li> Network cache is disabled.</li></ul>"
-            "Until you close the window, you can still click the Back and Forward buttons"
-            " to return to the webpages you have opened.").arg(title);
+        QString text1 = tr("When private browsing is turned on, some actions concerning your privacy will be disabled:");
 
-        QMessageBox::StandardButton button = QMessageBox::question(this, QString(), text,
-                               QMessageBox::Ok | QMessageBox::Cancel,
-                               QMessageBox::Ok);
-        if (button == QMessageBox::Ok) {
+        QStringList actions;
+        actions.append(tr("Webpages are not added to the history."));
+        actions.append(tr("Items are automatically removed from the Downloads window."));
+        actions.append(tr("New cookies are not stored, current cookies can't be accessed."));
+        actions.append(tr("Site icons won't be stored."));
+        actions.append(tr("Session won't be saved."));
+        actions.append(tr("Searches are not added to the pop-up menu in the search box."));
+        actions.append(tr("No new network cache is written to disk."));
+
+        QString text2 = tr("Until you close the window, you can still click the Back and Forward "
+                           "buttons to return to the webpages you have opened.");
+
+        QString message = QString(QLatin1String("<b>%1</b><p>%2</p><ul><li>%3</li></ul><p>%4</p>"))
+                          .arg(title, text1, actions.join(QLatin1String("</li><li>")), text2);
+
+        QMessageBox::StandardButton button = QMessageBox::question(this, tr("Private Browsing"), message,
+                                                                   QMessageBox::Ok | QMessageBox::Cancel,
+                                                                   QMessageBox::Ok);
+        if (button == QMessageBox::Ok)
             BrowserApplication::setPrivate(true);
-        } else {
+        else
             m_filePrivateBrowsingAction->setChecked(false);
-        }
     } else {
         BrowserApplication::setPrivate(false);
     }
@@ -1210,6 +1283,8 @@ void BrowserMainWindow::closeEvent(QCloseEvent *event)
 {
     if (!BrowserApplication::instance()->allowToCloseWindow(this)) {
         event->ignore();
+        if (m_tabWidget->count() == 0)
+            m_tabWidget->newTab();
         return;
     }
 
@@ -1231,7 +1306,6 @@ void BrowserMainWindow::closeEvent(QCloseEvent *event)
     }
 
     event->accept();
-    deleteLater();
 }
 
 void BrowserMainWindow::mousePressEvent(QMouseEvent *event)
@@ -1299,15 +1373,11 @@ void BrowserMainWindow::viewFullScreen(bool makeFullScreen)
 
         menuBar()->hide();
         statusBar()->hide();
-
-        updateStatusbarActionText(false);
     } else {
         setWindowState(windowState() & ~Qt::WindowFullScreen);
 
         menuBar()->setVisible(m_menuBarVisible);
         statusBar()->setVisible(m_statusBarVisible);
-
-        updateStatusbarActionText(m_statusBarVisible);
     }
 }
 
@@ -1319,7 +1389,7 @@ void BrowserMainWindow::viewPageSource()
     QString title = currentTab()->title();
     QString markup = currentTab()->page()->mainFrame()->toHtml();
     QUrl url = currentTab()->url();
-    SourceViewer *viewer = new SourceViewer(markup, title, url, this);
+    SourceViewer *viewer = new SourceViewer(markup, title, url);
     viewer->setAttribute(Qt::WA_DeleteOnClose);
     viewer->show();
 }
@@ -1364,8 +1434,8 @@ void BrowserMainWindow::toggleInspector(bool enable)
 void BrowserMainWindow::swapFocus()
 {
     if (currentTab()->hasFocus()) {
-        m_tabWidget->currentLineEdit()->setFocus();
-        m_tabWidget->currentLineEdit()->selectAll();
+        m_tabWidget->currentLocationBar()->setFocus();
+        m_tabWidget->currentLocationBar()->selectAll();
     } else {
         currentTab()->setFocus();
     }
@@ -1390,8 +1460,6 @@ void BrowserMainWindow::loadProgress(int progress)
 {
     if (progress < 100 && progress > 0) {
         disconnect(m_stopReloadAction, SIGNAL(triggered()), m_viewReloadAction, SLOT(trigger()));
-        if (m_stopIcon.isNull())
-            m_stopIcon = style()->standardIcon(QStyle::SP_BrowserStop);
         m_stopReloadAction->setIcon(m_stopIcon);
         connect(m_stopReloadAction, SIGNAL(triggered()), m_viewStopAction, SLOT(trigger()));
         m_stopReloadAction->setToolTip(tr("Stop loading the current page"));
@@ -1403,6 +1471,12 @@ void BrowserMainWindow::loadProgress(int progress)
     }
 }
 
+void BrowserMainWindow::showSearchDialog()
+{
+    OpenSearchDialog dialog(this);
+    dialog.exec();
+}
+
 void BrowserMainWindow::aboutToShowBackMenu()
 {
     m_historyBackMenu->clear();
@@ -1445,7 +1519,13 @@ void BrowserMainWindow::aboutToShowWindowMenu()
     m_windowMenu->addAction(m_tabWidget->nextTabAction());
     m_windowMenu->addAction(m_tabWidget->previousTabAction());
     m_windowMenu->addSeparator();
-    m_windowMenu->addAction(tr("Downloads"), this, SLOT(downloadManager()), QKeySequence(tr("Ctrl+Y", "Download Manager")));
+    QAction *downloadManagerAction = m_windowMenu->addAction(tr("Downloads"), this, SLOT(downloadManager()), QKeySequence(tr("Ctrl+Y", "Download Manager")));
+
+#if QT_VERSION >= 0x040600
+    downloadManagerAction->setIcon(QIcon::fromTheme(QLatin1String("emblem-downloads")));
+#else
+    Q_UNUSED(downloadManagerAction);
+#endif
 
     m_windowMenu->addSeparator();
     QList<BrowserMainWindow*> windows = BrowserApplication::instance()->mainWindows();
