@@ -63,6 +63,8 @@
 #include "settings.h"
 
 #include "acceptlanguagedialog.h"
+#include "autofilldialog.h"
+#include "autofillmanager.h"
 #include "browserapplication.h"
 #include "browsermainwindow.h"
 #include "cookiedialog.h"
@@ -81,12 +83,11 @@
 #include <qmetaobject.h>
 #include <qmessagebox.h>
 #include <qsettings.h>
+#include <qfiledialog.h>
 
 SettingsDialog::SettingsDialog(QWidget *parent)
     : QDialog(parent)
-#if QT_VERSION >= 0x040500
     , m_cacheEnabled(false)
-#endif
 {
     setupUi(this);
     connect(exceptionsButton, SIGNAL(clicked()), this, SLOT(showExceptions()));
@@ -95,15 +96,15 @@ SettingsDialog::SettingsDialog(QWidget *parent)
     connect(standardFontButton, SIGNAL(clicked()), this, SLOT(chooseFont()));
     connect(fixedFontButton, SIGNAL(clicked()), this, SLOT(chooseFixedFont()));
     connect(languageButton, SIGNAL(clicked()), this, SLOT(chooseAcceptLanguage()));
+    connect(downloadDirectoryButton, SIGNAL(clicked()), this, SLOT(chooseDownloadDirectory()));
+    connect(styleSheetBrowseButton, SIGNAL(clicked()), this, SLOT(chooseStyleSheet()));
+
+    connect(editAutoFillUserButton, SIGNAL(clicked()), this, SLOT(editAutoFillUser()));
 
-#if QT_VERSION < 0x040500
-    oneCloseButton->setVisible(false); // no other mode than one close button with qt <4.5
-    networkCache->setVisible(false);
-#else
     // As network cache has too many bugs in 4.5.1, do not allow to enable it.
     if (QLatin1String(qVersion()) == QLatin1String("4.5.1"))
         networkCache->setVisible(false);
-#endif
+
     loadDefaults();
     loadFromSettings();
 }
@@ -128,12 +129,19 @@ void SettingsDialog::loadDefaults()
     enablePlugins->setChecked(defaultSettings->testAttribute(QWebSettings::PluginsEnabled));
     enableImages->setChecked(defaultSettings->testAttribute(QWebSettings::AutoLoadImages));
     clickToFlash->setChecked(false);
-    filterTrackingCookiesCheckbox->setChecked(true);
+    cookieSessionCombo->setCurrentIndex(0);
+    filterTrackingCookiesCheckbox->setChecked(false);
+
+    autoFillPasswordFormsCheckBox->setChecked(false);
 }
 
 void SettingsDialog::loadFromSettings()
 {
     QSettings settings;
+    settings.beginGroup(QLatin1String("Settings"));
+    tabWidget->setCurrentIndex(settings.value(QLatin1String("currentTab"), 0).toInt());
+    settings.endGroup();
+
     settings.beginGroup(QLatin1String("MainWindow"));
     QString defaultHome = QLatin1String("about:home");
     homeLineEdit->setText(settings.value(QLatin1String("home"), defaultHome).toString());
@@ -188,9 +196,8 @@ void SettingsDialog::loadFromSettings()
     // Privacy
     settings.beginGroup(QLatin1String("cookies"));
 
-    CookieJar *jar = BrowserApplication::cookieJar();
     QByteArray value = settings.value(QLatin1String("acceptCookies"), QLatin1String("AcceptOnlyFromSitesNavigatedTo")).toByteArray();
-    QMetaEnum acceptPolicyEnum = jar->staticMetaObject.enumerator(jar->staticMetaObject.indexOfEnumerator("AcceptPolicy"));
+    QMetaEnum acceptPolicyEnum = CookieJar::staticMetaObject.enumerator(CookieJar::staticMetaObject.indexOfEnumerator("AcceptPolicy"));
     CookieJar::AcceptPolicy acceptCookies = acceptPolicyEnum.keyToValue(value) == -1 ?
                         CookieJar::AcceptOnlyFromSitesNavigatedTo :
                         static_cast<CookieJar::AcceptPolicy>(acceptPolicyEnum.keyToValue(value));
@@ -207,7 +214,7 @@ void SettingsDialog::loadFromSettings()
     }
 
     value = settings.value(QLatin1String("keepCookiesUntil"), QLatin1String("Expire")).toByteArray();
-    QMetaEnum keepPolicyEnum = jar->staticMetaObject.enumerator(jar->staticMetaObject.indexOfEnumerator("KeepPolicy"));
+    QMetaEnum keepPolicyEnum = CookieJar::staticMetaObject.enumerator(CookieJar::staticMetaObject.indexOfEnumerator("KeepPolicy"));
     CookieJar::KeepPolicy keepCookies = keepPolicyEnum.keyToValue(value) == -1 ?
                         CookieJar::KeepUntilExpire :
                         static_cast<CookieJar::KeepPolicy>(keepPolicyEnum.keyToValue(value));
@@ -222,17 +229,25 @@ void SettingsDialog::loadFromSettings()
         keepUntilCombo->setCurrentIndex(2);
         break;
     }
-    filterTrackingCookiesCheckbox->setChecked(settings.value(QLatin1String("filterTrackingCookies"), true).toBool());
+    int sessionLength = settings.value(QLatin1String("sessionLength"), -1).toInt();
+    switch (sessionLength) {
+    case 1: cookieSessionCombo->setCurrentIndex(1); break;
+    case 2: cookieSessionCombo->setCurrentIndex(2); break;
+    case 3: cookieSessionCombo->setCurrentIndex(3); break;
+    case 7: cookieSessionCombo->setCurrentIndex(4); break;
+    case 30: cookieSessionCombo->setCurrentIndex(5); break;
+    default:
+    case 0: cookieSessionCombo->setCurrentIndex(0); break;
+    }
+    filterTrackingCookiesCheckbox->setChecked(settings.value(QLatin1String("filterTrackingCookies"), false).toBool());
     settings.endGroup();
 
-#if QT_VERSION >= 0x040500
     // Network
     settings.beginGroup(QLatin1String("network"));
     m_cacheEnabled = settings.value(QLatin1String("cacheEnabled"), true).toBool();
     networkCache->setChecked(m_cacheEnabled);
     networkCacheMaximumSizeSpinBox->setValue(settings.value(QLatin1String("maximumCacheSize"), 50).toInt());
     settings.endGroup();
-#endif
 
     // Proxy
     settings.beginGroup(QLatin1String("proxy"));
@@ -248,18 +263,24 @@ void SettingsDialog::loadFromSettings()
     settings.beginGroup(QLatin1String("tabs"));
     selectTabsWhenCreated->setChecked(settings.value(QLatin1String("selectNewTabs"), false).toBool());
     confirmClosingMultipleTabs->setChecked(settings.value(QLatin1String("confirmClosingMultipleTabs"), true).toBool());
-#if QT_VERSION >= 0x040500
     oneCloseButton->setChecked(settings.value(QLatin1String("oneCloseButton"),false).toBool());
-#endif
     quitAsLastTabClosed->setChecked(settings.value(QLatin1String("quitAsLastTabClosed"), true).toBool());
     openTargetBlankLinksIn->setCurrentIndex(settings.value(QLatin1String("openTargetBlankLinksIn"), TabWidget::NewSelectedTab).toInt());
     openLinksFromAppsIn->setCurrentIndex(settings.value(QLatin1String("openLinksFromAppsIn"), TabWidget::NewSelectedTab).toInt());
     settings.endGroup();
+
+    settings.beginGroup(QLatin1String("autofill"));
+    autoFillPasswordFormsCheckBox->setChecked(settings.value(QLatin1String("passwordForms"), true).toBool());
+    settings.endGroup();
 }
 
 void SettingsDialog::saveToSettings()
 {
     QSettings settings;
+    settings.beginGroup(QLatin1String("Settings"));
+    settings.setValue(QLatin1String("currentTab"), tabWidget->currentIndex());
+    settings.endGroup();
+
     settings.beginGroup(QLatin1String("MainWindow"));
     settings.setValue(QLatin1String("home"), homeLineEdit->text());
     settings.setValue(QLatin1String("startupBehavior"), startupBehavior->currentIndex());
@@ -322,8 +343,7 @@ void SettingsDialog::saveToSettings()
         break;
     }
 
-    CookieJar *jar = BrowserApplication::cookieJar();
-    QMetaEnum acceptPolicyEnum = jar->staticMetaObject.enumerator(jar->staticMetaObject.indexOfEnumerator("AcceptPolicy"));
+    QMetaEnum acceptPolicyEnum = CookieJar::staticMetaObject.enumerator(CookieJar::staticMetaObject.indexOfEnumerator("AcceptPolicy"));
     settings.setValue(QLatin1String("acceptCookies"), QLatin1String(acceptPolicyEnum.valueToKey(acceptCookies)));
 
     CookieJar::KeepPolicy keepPolicy;
@@ -340,18 +360,27 @@ void SettingsDialog::saveToSettings()
         break;
     }
 
-    QMetaEnum keepPolicyEnum = jar->staticMetaObject.enumerator(jar->staticMetaObject.indexOfEnumerator("KeepPolicy"));
+    QMetaEnum keepPolicyEnum = CookieJar::staticMetaObject.enumerator(CookieJar::staticMetaObject.indexOfEnumerator("KeepPolicy"));
     settings.setValue(QLatin1String("keepCookiesUntil"), QLatin1String(keepPolicyEnum.valueToKey(keepPolicy)));
+    int sessionLength = cookieSessionCombo->currentIndex();
+    switch (sessionLength) {
+    case 1: sessionLength = 1; break;
+    case 2: sessionLength = 2; break;
+    case 3: sessionLength = 3; break;
+    case 4: sessionLength = 7; break;
+    case 5: sessionLength = 30; break;
+    default:
+    case 0: sessionLength = -1; break;
+    }
+    settings.setValue(QLatin1String("sessionLength"), sessionLength);
     settings.setValue(QLatin1String("filterTrackingCookies"), filterTrackingCookiesCheckbox->isChecked());
     settings.endGroup();
 
-#if QT_VERSION >= 0x040500
     // Network
     settings.beginGroup(QLatin1String("network"));
     settings.setValue(QLatin1String("cacheEnabled"), networkCache->isChecked());
     settings.setValue(QLatin1String("maximumCacheSize"), networkCacheMaximumSizeSpinBox->value());
     settings.endGroup();
-#endif
 
     // proxy
     settings.beginGroup(QLatin1String("proxy"));
@@ -367,18 +396,21 @@ void SettingsDialog::saveToSettings()
     settings.beginGroup(QLatin1String("tabs"));
     settings.setValue(QLatin1String("selectNewTabs"), selectTabsWhenCreated->isChecked());
     settings.setValue(QLatin1String("confirmClosingMultipleTabs"), confirmClosingMultipleTabs->isChecked());
-#if QT_VERSION >= 0x040500
     settings.setValue(QLatin1String("oneCloseButton"), oneCloseButton->isChecked());
-#endif
     settings.setValue(QLatin1String("quitAsLastTabClosed"), quitAsLastTabClosed->isChecked());
     settings.setValue(QLatin1String("openTargetBlankLinksIn"), openTargetBlankLinksIn->currentIndex());
     settings.setValue(QLatin1String("openLinksFromAppsIn"), openLinksFromAppsIn->currentIndex());
     settings.endGroup();
 
+    settings.beginGroup(QLatin1String("autofill"));
+    settings.setValue(QLatin1String("passwordForms"), autoFillPasswordFormsCheckBox->isChecked());
+    settings.endGroup();
+
     BrowserApplication::instance()->loadSettings();
     BrowserApplication::networkAccessManager()->loadSettings();
     BrowserApplication::cookieJar()->loadSettings();
     BrowserApplication::historyManager()->loadSettings();
+    BrowserApplication::autoFillManager()->loadSettings();
 
     WebPage::webPluginFactory()->refreshPlugins();
 
@@ -391,14 +423,12 @@ void SettingsDialog::saveToSettings()
 void SettingsDialog::accept()
 {
     saveToSettings();
-#if QT_VERSION >= 0x040500
     // Due to a bug in Qt <= 4.5.1, enabling/disabling cache requires the browser to be restarted.
     if (QLatin1String(qVersion()) <= QLatin1String("4.5.1") && networkCache->isChecked() != m_cacheEnabled) {
         QMessageBox::information(this, tr("Restart required"),
                                  tr("The network cache configuration has changed. "
                                     "So that it can be taken into account, the browser has to be restarted."));
     }
-#endif
     QDialog::accept();
 }
 
@@ -414,6 +444,12 @@ void SettingsDialog::showExceptions()
     dialog.exec();
 }
 
+void SettingsDialog::chooseDownloadDirectory()
+{
+    QString fileName = QFileDialog::getExistingDirectory(this, tr("Choose Directory"), downloadsLocation->text());
+    downloadsLocation->setText(fileName);
+}
+
 void SettingsDialog::chooseFont()
 {
     bool ok;
@@ -448,3 +484,16 @@ void SettingsDialog::chooseAcceptLanguage()
     dialog.exec();
 }
 
+void SettingsDialog::chooseStyleSheet()
+{
+    QUrl url = QUrl::fromEncoded(userStyleSheet->text().toUtf8());
+    QString fileName = QFileDialog::getOpenFileName(this, tr("Choose CSS File"), url.toLocalFile());
+    userStyleSheet->setText(QString::fromUtf8(QUrl::fromLocalFile(fileName).toEncoded()));
+}
+
+void SettingsDialog::editAutoFillUser()
+{
+    AutoFillDialog dialog;
+    dialog.exec();
+}
+
